==> aroundme_0_6_2.tar.tgz: aroundme_0_6_2/aroundme/language/1/barnraiser_01/my_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'common.lang.php');

//HEADER
$lang['hdr_network'] = 							"my network summary";
$lang['hdr_blog'] = 							"my blog summary";


// HREF
$lang['href_view_relations'] = 					"view your contacts";
$lang['href_invite_relations'] = 				"invite people into your network";
$lang['href_view_directory'] = 					"view the network directory";
$lang['href_add_blog_entry'] = 					"write a new blog entry";
$lang['href_view_blog'] = 						"view your blog";


// BODY
// Do not replace 'INCTOTAL' if translating. This text is replaced with a number automatically.
$lang['txt_degree1'] = 							"You have INCTOTAL_DEG first degree contacts in this network.";
$lang['txt_network'] = 							"There are INCTOTAL_USERS people in this network INCTTOTAL_ONLINE of which are online now.";
$lang['txt_my_overview'] = 						"my overview"; // breadcrumb
$lang['txt_blog_intro'] = 						"A blog is a short name for 'web log'. It is your Internet based diary.";
$lang['txt_blog'] = 							"You have written INCTOTAL_BLOG blog entries.";
$lang['txt_blog_comments'] = 					"You have received INCTOTAL_COMMENTS comments against your blog entries.";
$lang['txt_latest_comment'] = 					"latest comment.";

?>

==> aroundme_0_6_6.tar.tgz: aroundme_0_6_6/aroundme/language/1/barnraiser_01/my_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//HEADER
$lang['hdr_network'] = 							"my network summary";
$lang['hdr_blog'] = 							"my blog summary";


// HREF
$lang['href_view_relations'] = 					"view your contacts";
$lang['href_invite_relations'] = 				"invite people into your network";
$lang['href_view_directory'] = 					"view the network directory";
$lang['href_add_blog_entry'] = 					"write a new blog entry";
$lang['href_view_blog'] = 						"view your blog";


// BODY
// Do not replace 'INCTOTAL' if translating. This text is replaced with a number automatically.
$lang['txt_degree1'] = 							"You have SYS_KEYWORD_DEG_TOTAL first degree contacts in this network.";
$lang['txt_network'] = 							"There are SYS_KEYWORD_USRS_TOTAL people in this network SYS_KEYWORD_USERS_ONLINE_TOTAL of which are online now.";
$lang['txt_blog_intro'] = 						"A blog is a short name for 'web log'. It is your Internet based diary.";
$lang['txt_blog'] = 							"You have written SYS_KEYWORD_BLG_TOTAL blog entries.";
$lang['txt_blog_comments'] = 					"You have received SYS_KEYWORD_COM_TOTAL comments against your blog entries.";
$lang['txt_latest_comment'] = 					"latest comment.";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"my overview";

?>
